==> cecil_0.3.orig.tar.gz: cecil-0.3/Mono.Cecil/IMarshalSpec.cs <==
//
// IMarshalSpec.cs
//
// Author:
//   Jb Evain (jbevain@gmail.com)
//
// (C) 2005 Jb Evain
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
//
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

namespace Mono.Cecil {

	using System;

	public interface IMarshalSpec : IReflectionVisitable {

		NativeType NativeIntrinsic { get; }
		IHasMarshalSpec Container { get; }
	}

	public interface IArrayDesc : IMarshalSpec {

		NativeType ElemType { get; set; }
		int ParamNum { get; set; }
		int ElemMult { get; set; }
		int NumElem { get; set; }
	}

	public interface ICustomMarshalerDesc : IMarshalSpec {

		Guid Guid { get; set; }
		string UnmanagedType { get; set; }
		TypeDefinition ManagedType { get; set; }
		string Cookie { get; set; }
	}

	public interface IFixedArrayDesc : IMarshalSpec {

		int NumElem { get; set; }
		NativeType ElemType { get; set; }
	}

	public interface ISafeArrayDesc : IMarshalSpec {

		VariantType ElemType { get; set; }
	}

	public interface IFixedSysStringDesc : IMarshalSpec {

		int Size { get; set; }
	}
}

==> cecil_0.4.3.orig.tar.gz: cecil-0.4.3/Mono.Cecil/IMarshalSpec.cs <==
//
// IMarshalSpec.cs
//
// Author:
//   Jb Evain (jbevain@gmail.com)
//
// (C) 2005 Jb Evain
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
//
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

namespace Mono.Cecil {

	using System;

	public interface IMarshalSpec : IReflectionVisitable {

		NativeType NativeIntrinsic { get; }
		IHasMarshalSpec Container { get; }
	}

	public interface IArrayDesc : IMarshalSpec {

		NativeType ElemType { get; set; }
		int ParamNum { get; set; }
		int ElemMult { get; set; }
		int NumElem { get; set; }
	}

	public interface ICustomMarshalerDesc : IMarshalSpec {

		Guid Guid { get; set; }
		string UnmanagedType { get; set; }
		string ManagedType { get; set; }
		string Cookie { get; set; }
	}

	public interface IFixedArrayDesc : IMarshalSpec {

		int NumElem { get; set; }
		NativeType ElemType { get; set; }
	}

	public interface ISafeArrayDesc : IMarshalSpec {

		VariantType ElemType { get; set; }
	}

	public interface IFixedSysStringDesc : IMarshalSpec {

		int Size { get; set; }
	}
}
